==> forestry_1.11.2-5.3.0.10-sources.jar: forestry/core/gui/GuiUtil.java <==
/*******************************************************************************
 * Copyright (c) 2011-2014 SirSengir.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl-3.0.txt
 *
 * Various Contributors including, but not limited to:
 * SirSengir (original work), CovertJaguar, Player, Binnie, MysteriousAges
 ******************************************************************************/
package forestry.core.gui;

import java.util.Collection;
import java.util.List;

import forestry.core.gui.tooltips.IToolTipProvider;
import forestry.core.gui.tooltips.ToolTip;
import forestry.core.proxy.Proxies;
import net.minecraft.client.gui.FontRenderer;
import net.minecraft.client.gui.ScaledResolution;
import net.minecraft.client.renderer.GlStateManager;
import net.minecraft.client.renderer.RenderItem;
import net.minecraft.item.ItemStack;
import net.minecraftforge.fml.client.config.GuiUtils;

public class GuiUtil {
	public static void drawItemStack(GuiForestry gui, ItemStack stack, int xPos, int yPos) {
		FontRenderer font = null;
		if (!stack.func_190926_b()) {
			font = stack.func_77973_b().getFontRenderer(stack);
		}
		if (font == null) {
			font = gui.getFontRenderer();
		}

		RenderItem itemRender = Proxies.common.getClientInstance().func_175599_af();
		itemRender.func_180450_b(stack, xPos, yPos);
		itemRender.func_180453_a(font, stack, xPos, yPos, null);
	}

	public static void drawToolTips(GuiForestry gui, ToolTip toolTips, int mouseX, int mouseY) {
		List<String> lines = toolTips.getLines();
		if (!lines.isEmpty()) {
			GlStateManager.func_179094_E();
			GlStateManager.func_179109_b(-gui.getGuiLeft(), -gui.getGuiTop(), 0);
			ScaledResolution scaledresolution = new ScaledResolution(gui.field_146297_k);
			GuiUtils.drawHoveringText(lines, mouseX, mouseY, scaledresolution.func_78326_a(), scaledresolution.func_78328_b(), -1, gui.field_146297_k.field_71466_p);
			GlStateManager.func_179121_F();
		}
	}

	public static void drawToolTips(GuiForestry gui, Collection<?> objects, int mouseX, int mouseY) {
		for (Object obj : objects) {
			if (!(obj instanceof IToolTipProvider)) {
				continue;
			}
			IToolTipProvider provider = (IToolTipProvider) obj;
			if (!provider.isToolTipVisible()) {
				continue;
			}
			ToolTip tips = provider.getToolTip(mouseX - gui.getGuiLeft(), mouseY - gui.getGuiTop());
			if (tips == null) {
				continue;
			}
			boolean mouseOver = provider.isMouseOver(mouseX - gui.getGuiLeft(), mouseY - gui.getGuiTop());
			tips.onTick(mouseOver);
			if (mouseOver && tips.isReady()) {
				tips.refresh();
				drawToolTips(gui, tips, mouseX, mouseY);
			}
		}
	}
}

==> forestry_1.11.2-5.3.4.132-sources.jar: forestry/core/gui/GuiUtil.java <==
/*******************************************************************************
 * Copyright (c) 2011-2014 SirSengir.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl-3.0.txt
 *
 * Various Contributors including, but not limited to:
 * SirSengir (original work), CovertJaguar, Player, Binnie, MysteriousAges
 ******************************************************************************/
package forestry.core.gui;

import java.util.Collection;
import java.util.List;

import forestry.core.gui.tooltips.IToolTipProvider;
import forestry.core.gui.tooltips.ToolTip;
import net.minecraft.client.Minecraft;
import net.minecraft.client.gui.FontRenderer;
import net.minecraft.client.gui.ScaledResolution;
import net.minecraft.client.renderer.GlStateManager;
import net.minecraft.client.renderer.RenderItem;
import net.minecraft.item.ItemStack;
import net.minecraftforge.fml.client.config.GuiUtils;
import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

@SideOnly(Side.CLIENT)
public class GuiUtil {
	public static void drawItemStack(GuiForestry gui, ItemStack stack, int xPos, int yPos) {
		FontRenderer font = null;
		if (!stack.func_190926_b()) {
			font = stack.func_77973_b().getFontRenderer(stack);
		}
		if (font == null) {
			font = gui.getFontRenderer();
		}

		RenderItem itemRender = Minecraft.func_71410_x().func_175599_af();
		itemRender.func_180450_b(stack, xPos, yPos);
		itemRender.func_180453_a(font, stack, xPos, yPos, null);
	}

	public static void drawToolTips(GuiForestry gui, ToolTip toolTips, int mouseX, int mouseY) {
		List<String> lines = toolTips.getLines();
		if (!lines.isEmpty()) {
			GlStateManager.func_179094_E();
			GlStateManager.func_179109_b(-gui.getGuiLeft(), -gui.getGuiTop(), 0);
			ScaledResolution scaledresolution = new ScaledResolution(gui.field_146297_k);
			GuiUtils.drawHoveringText(lines, mouseX, mouseY, scaledresolution.func_78326_a(), scaledresolution.func_78328_b(), -1, gui.field_146297_k.field_71466_p);
			GlStateManager.func_179121_F();
		}
	}

	public static void drawToolTips(GuiForestry gui, Collection<?> objects, int mouseX, int mouseY) {
		for (Object obj : objects) {
			if (!(obj instanceof IToolTipProvider)) {
				continue;
			}
			IToolTipProvider provider = (IToolTipProvider) obj;
			if (!provider.isToolTipVisible()) {
				continue;
			}
			ToolTip tips = provider.getToolTip(mouseX - gui.getGuiLeft(), mouseY - gui.getGuiTop());
			if (tips == null) {
				continue;
			}
			boolean mouseOver = provider.isMouseOver(mouseX - gui.getGuiLeft(), mouseY - gui.getGuiTop());
			tips.onTick(mouseOver);
			if (mouseOver && tips.isReady()) {
				tips.refresh();
				drawToolTips(gui, tips, mouseX, mouseY);
			}
		}
	}
}
